=====
Brine
=====

* Documentation: https://docs.brine.io

What is it?
-----------

**Brine** is a dataset manager for computer vision data. You can use Brine to
easily install and load image datasets in Python. Brine also integrates with
popular ML frameworks like Keras and PyTorch (Tensorflow coming soon!) so you
can easily use your datasets in those frameworks.

With Brine, you don't need to deal with a bunch of random data formats. Datasets
are just a `brine install` away.

Installation
------------

::

  $ pip install brine-io

License
-------

The brine python client is distributed under the Apache License, Version 2.0.
